Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(538)

Unified Diff: web_apks/minting_example/junit/libs/runtime_library/src/org/chromium/minting/libs/runtime_library/WebApkServiceImplTest.java

Issue 1953543002: Rename WebAPK related classes to be of the format *WebApk*.java (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: web_apks/minting_example/junit/libs/runtime_library/src/org/chromium/minting/libs/runtime_library/WebApkServiceImplTest.java
diff --git a/web_apks/minting_example/junit/libs/runtime_library/src/org/chromium/minting/libs/runtime_library/MintedServiceImplTest.java b/web_apks/minting_example/junit/libs/runtime_library/src/org/chromium/minting/libs/runtime_library/WebApkServiceImplTest.java
similarity index 83%
rename from web_apks/minting_example/junit/libs/runtime_library/src/org/chromium/minting/libs/runtime_library/MintedServiceImplTest.java
rename to web_apks/minting_example/junit/libs/runtime_library/src/org/chromium/minting/libs/runtime_library/WebApkServiceImplTest.java
index 58a54a03b84464d762fad89199dea01ef98a9fcd..14705064d4dbee40671e205f4fbf0816794ec003 100644
--- a/web_apks/minting_example/junit/libs/runtime_library/src/org/chromium/minting/libs/runtime_library/MintedServiceImplTest.java
+++ b/web_apks/minting_example/junit/libs/runtime_library/src/org/chromium/minting/libs/runtime_library/WebApkServiceImplTest.java
@@ -22,11 +22,11 @@ import org.robolectric.Robolectric;
import org.robolectric.annotation.Config;
/**
* Unit tests for {@link org.chromium.minting.MintedServiceImpl}.
*/
@RunWith(LocalRobolectricTestRunner.class)
@Config(manifest = Config.NONE)
-public class MintedServiceImplTest {
+public class WebApkServiceImplTest {
private static final String ALLOWED_PACKAGE = "com.allowed.package";
private static final int ALLOWED_UID = 0;
@@ -42,21 +42,21 @@ public class MintedServiceImplTest {
@Test
public void testAllowedCaller() {
- MintedServiceImpl service =
- new MintedServiceImpl(Robolectric.application, createBundle(ALLOWED_PACKAGE));
+ WebApkServiceImpl service =
+ new WebApkServiceImpl(Robolectric.application, createBundle(ALLOWED_PACKAGE));
assertTrue(service.checkHasAccess(ALLOWED_UID, mPackageManager));
}
@Test
public void testProhibitedCaller() {
- MintedServiceImpl service =
- new MintedServiceImpl(Robolectric.application, createBundle(ALLOWED_PACKAGE));
+ WebApkServiceImpl service =
+ new WebApkServiceImpl(Robolectric.application, createBundle(ALLOWED_PACKAGE));
assertFalse(service.checkHasAccess(ALLOWED_UID + 1, mPackageManager));
}
@Test
public void testOnTransactThrowsIfNoPermission() {
- MintedServiceImpl service = new MintedServiceImpl(
+ WebApkServiceImpl service = new WebApkServiceImpl(
Robolectric.application, createBundle(ALLOWED_PACKAGE)) {
@Override
boolean checkHasAccess(int uid, PackageManager packageManager) {
@@ -72,7 +72,7 @@ public class MintedServiceImplTest {
@Test
public void testOnTransactRunsIfHasPermission() {
- MintedServiceImpl service = new MintedServiceImpl(
+ WebApkServiceImpl service = new WebApkServiceImpl(
Robolectric.application, createBundle(ALLOWED_PACKAGE)) {
@Override
boolean checkHasAccess(int uid, PackageManager packageManager) {
@@ -88,13 +88,13 @@ public class MintedServiceImplTest {
}
/**
* Creates Bundle to pass to MintedServiceImpl constructor.
* @param expectedHostBrowser
* @return The bundle
*/
private static Bundle createBundle(String expectedHostBrowser) {
Bundle bundle = new Bundle();
- bundle.putString(MintedServiceImpl.KEY_EXPECTED_HOST_BROWSER, expectedHostBrowser);
+ bundle.putString(WebApkServiceImpl.KEY_EXPECTED_HOST_BROWSER, expectedHostBrowser);
return bundle;
}
}
@@ -22,11 +22,11 @@ import org.robolectric.Robolectric;
import org.robolectric.annotation.Config;
/**
- * Unit tests for {@link org.chromium.minting.MintedServiceImpl}.
+ * Unit tests for {@link org.chromium.minting.WebApkServiceImpl}.
*/
@@ -88,13 +88,13 @@ public class MintedServiceImplTest {
}
/**
- * Creates Bundle to pass to MintedServiceImpl constructor.
+ * Creates Bundle to pass to WebApkServiceImpl constructor.
* @param expectedHostBrowser
* @return The bundle

Powered by Google App Engine
This is Rietveld 408576698